#ifndef VAL_INLINE_CONF_H
#define VAL_INLINE_CONF_H

#ifdef LIBVAL_INLINE_POLICY
const char val_conf_inline_buf[] = """##################################\n"
"# Includes \n"
"##################################\n"
"\n"
"# TRUSTMAN-ACTION bind-include /var/opt/named/named.conf\n"
"\n"
"##################################\n"
"# Global Options \n"
"##################################\n"
"\n"
"global-options\n"
"    trust-oob-answers yes\n"
"    edns0-size 1492\n"
"    env-policy disable\n"
"    app-policy disable\n"
";\n"
"\n"
"##################################\n"
"# Default policies \n"
"##################################\n"
"\n"
":	trust-anchor \n"
"                .  DS  19036  8  2  49AAC11D7B6F6446702E54A1607371607A1A41855200FD2CE1CDDE32F24E8FB5\n"
"                .  DS  20326  8  2  E06D44B80B8F1D39A95C0B0D7C65D08458E880409BBC683457104237C7F8EC8D\n"
";\n"
"\n"
": zone-security-expectation \n"
"                . validate\n"
";\n"
"\n"
": provably-insecure-status\n"
"                . trusted\n"
";\n"
"   \n"
": clock-skew\n"
"                . 0\n"
";\n"
"\n"
"##################################\n"
"# MTA Policies\n"
"##################################\n"
"    \n"
"mta provably-insecure-status\n"
"                . trusted\n"
";\n"
"   \n"
"mta clock-skew\n"
"                . -1\n"
";\n"
"  \n"
"##################################\n"
"# Web Browser Policies \n"
"##################################\n"
"\n"
"browser provably-insecure-status\n"
"                . trusted\n"
";\n"
"\n"
"browser clock-skew\n"
"                . 0\n"
";\n";

const char root_hints_inline_buf[] = """;       This file holds the information on root name servers needed to\n"
";       initialize cache of Internet domain name servers\n"
";       (e.g. reference this file in the \"cache  .  <file>\"\n"
";       configuration file of BIND domain name servers).\n"
";\n"
";       This file is made available by InterNIC \n"
";       under anonymous FTP as\n"
";           file                /domain/named.cache\n"
";           on server           FTP.INTERNIC.NET\n"
";       -OR-                    RS.INTERNIC.NET\n"
";\n"
";       last update:    Jan 3, 2013\n"
";       related version of root zone:   2013010300\n"
";\n"
"; formerly NS.INTERNIC.NET\n"
";\n"
".                        3600000  IN  NS    A.ROOT-SERVERS.NET.\n"
"A.ROOT-SERVERS.NET.      3600000      A     198.41.0.4\n"
"A.ROOT-SERVERS.NET.      3600000      AAAA  2001:503:BA3E::2:30\n"
";\n"
"; FORMERLY NS1.ISI.EDU\n"
";\n"
".                        3600000      NS    B.ROOT-SERVERS.NET.\n"
"B.ROOT-SERVERS.NET.      3600000      A     192.228.79.201\n"
";\n"
"; FORMERLY C.PSI.NET\n"
";\n"
".                        3600000      NS    C.ROOT-SERVERS.NET.\n"
"C.ROOT-SERVERS.NET.      3600000      A     192.33.4.12\n"
";\n"
"; FORMERLY TERP.UMD.EDU\n"
";\n"
".                        3600000      NS    D.ROOT-SERVERS.NET.\n"
"D.ROOT-SERVERS.NET.      3600000      A     199.7.91.13\n"
"D.ROOT-SERVERS.NET.	 3600000      AAAA  2001:500:2D::D\n"
";\n"
"; FORMERLY NS.NASA.GOV\n"
";\n"
".                        3600000      NS    E.ROOT-SERVERS.NET.\n"
"E.ROOT-SERVERS.NET.      3600000      A     192.203.230.10\n"
";\n"
"; FORMERLY NS.ISC.ORG\n"
";\n"
".                        3600000      NS    F.ROOT-SERVERS.NET.\n"
"F.ROOT-SERVERS.NET.      3600000      A     192.5.5.241\n"
"F.ROOT-SERVERS.NET.      3600000      AAAA  2001:500:2F::F\n"
";\n"
"; FORMERLY NS.NIC.DDN.MIL\n"
";\n"
".                        3600000      NS    G.ROOT-SERVERS.NET.\n"
"G.ROOT-SERVERS.NET.      3600000      A     192.112.36.4\n"
";\n"
"; FORMERLY AOS.ARL.ARMY.MIL\n"
";\n"
".                        3600000      NS    H.ROOT-SERVERS.NET.\n"
"H.ROOT-SERVERS.NET.      3600000      A     198.97.190.53\n"
"H.ROOT-SERVERS.NET.      3600000      AAAA  2001:500:1::53\n"
";\n"
"; FORMERLY NIC.NORDU.NET\n"
";\n"
".                        3600000      NS    I.ROOT-SERVERS.NET.\n"
"I.ROOT-SERVERS.NET.      3600000      A     192.36.148.17\n"
"I.ROOT-SERVERS.NET.      3600000      AAAA  2001:7FE::53\n"
";\n"
"; OPERATED BY VERISIGN, INC.\n"
";\n"
".                        3600000      NS    J.ROOT-SERVERS.NET.\n"
"J.ROOT-SERVERS.NET.      3600000      A     192.58.128.30\n"
"J.ROOT-SERVERS.NET.      3600000      AAAA  2001:503:C27::2:30\n"
";\n"
"; OPERATED BY RIPE NCC\n"
";\n"
".                        3600000      NS    K.ROOT-SERVERS.NET.\n"
"K.ROOT-SERVERS.NET.      3600000      A     193.0.14.129\n"
"K.ROOT-SERVERS.NET.      3600000      AAAA  2001:7FD::1\n"
";\n"
"; OPERATED BY ICANN\n"
";\n"
".                        3600000      NS    L.ROOT-SERVERS.NET.\n"
"L.ROOT-SERVERS.NET.      3600000      A     199.7.83.42\n"
"L.ROOT-SERVERS.NET.      3600000      AAAA  2001:500:3::42\n"
";\n"
"; OPERATED BY WIDE\n"
";\n"
".                        3600000      NS    M.ROOT-SERVERS.NET.\n"
"M.ROOT-SERVERS.NET.      3600000      A     202.12.27.33\n"
"M.ROOT-SERVERS.NET.      3600000      AAAA  2001:DC3::35\n"
"; End of File\n";

const char resolv_conf_inline_buf[] = """#nameserver 127.0.0.1\n";
#else
const char val_conf_inline_buf[] = "";
const char root_hints_inline_buf[] = "";
const char resolv_conf_inline_buf[] = "";
#endif

#endif
